@@ -12,16 +12,6 @@ import platform
 import struct
 import sys
 
-# Monkey-patch 3.4 and below
-
-if sys.version_info < (3,5):
-
-    def home_path() -> pathlib.Path:
-
-        return pathlib.Path(os.path.expanduser("~"))
-
-    pathlib.Path.home = home_path
-
 __all__ = ["make", "sources"]
 
 BITNESS = struct.calcsize("P") * 8
